import { h } from '../iiifgallery.core.js';

class IIIFGallery {
    constructor() {
        this.items = null;
    }
    manifestHandler() {
        this._reset();
    }
    ignoreHandler() {
        this._reset();
    }
    componentWillLoad() {
        this._reset();
    }
    _reset() {
        if (this.manifest) {
            manifesto.loadManifest(this.manifest).then((data) => {
                const manifest = manifesto.create(data);
                if (manifest.isCollection()) {
                    this.items = manifest.items;
                }
                else {
                    const sequences = manifest.getSequences();
                    if (sequences.length) {
                        const sequence = sequences[0];
                        this.items = sequence.getCanvases();
                    }
                }
                if (this.ignore) {
                    const ignore = this.ignore.split(',').map((item) => item.trim());
                    this.items = this.items.filter(resource => ignore.indexOf(resource.id) === -1);
                }
            }).catch(function (e) {
                console.error(e);
                console.error('failed to load manifest');
            });
        }
        else {
            this.items = null;
        }
    }
    reset() {
        this._reset();
    }
    render() {
        if (!this.items) {
            return (h("span", null));
        }
        else {
            return (h("section", { class: "cf w-100 pa2" }, this.items.map((item) => h("iiif-gallery-item", { item: item, selected: this._selectedItem === item }))));
        }
    }
    itemSelected(event) {
        const item = event.detail;
        this._selectedItem = item;
        if (item.isCollection()) {
            this.onSelectCollection.emit(item);
        }
        else if (item.isManifest()) {
            this.onSelectManifest.emit(item);
        }
        else {
            this.onSelectCanvas.emit(item);
        }
    }
    static get is() { return "iiif-gallery"; }
    static get properties() { return {
        "ignore": {
            "type": String,
            "attr": "ignore",
            "watchCallbacks": ["ignoreHandler"]
        },
        "items": {
            "state": true
        },
        "manifest": {
            "type": String,
            "attr": "manifest",
            "watchCallbacks": ["manifestHandler"]
        },
        "reset": {
            "method": true
        }
    }; }
    static get events() { return [{
            "name": "onSelectManifest",
            "method": "onSelectManifest",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onSelectCollection",
            "method": "onSelectCollection",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "onSelectCanvas",
            "method": "onSelectCanvas",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get listeners() { return [{
            "name": "onSelectItem",
            "method": "itemSelected"
        }]; }
    static get style() { return ""; }
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var classnames = createCommonjsModule(function (module) {
/*!
  Copyright (c) 2017 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/
/* global define */

(function () {

	var hasOwn = {}.hasOwnProperty;

	function classNames () {
		var classes = [];

		for (var i = 0; i < arguments.length; i++) {
			var arg = arguments[i];
			if (!arg) continue;

			var argType = typeof arg;

			if (argType === 'string' || argType === 'number') {
				classes.push(arg);
			} else if (Array.isArray(arg) && arg.length) {
				var inner = classNames.apply(null, arg);
				if (inner) {
					classes.push(inner);
				}
			} else if (argType === 'object') {
				for (var key in arg) {
					if (hasOwn.call(arg, key) && arg[key]) {
						classes.push(key);
					}
				}
			}
		}

		return classes.join(' ');
	}

	if (module.exports) {
		classNames.default = classNames;
		module.exports = classNames;
	} else {
		window.classNames = classNames;
	}
}());
});

class IIIFGalleryItem {
    constructor() {
        this.selected = false;
    }
    renderLabel() {
        let label = this.item.getDefaultLabel();
        if (label) {
            return (h("div", { class: "ph2 ph0-ns pb3 link" },
                h("h3", { class: "f5 f4-ns mb0 black-90" }, label)));
        }
    }
    render() {
        let thumbnail = this.item.getThumbnail();
        const classes = classnames({
            'collection': this.item.isCollection(),
            'manifest': this.item.isManifest(),
            'canvas': this.item.isCanvas(),
            'selected': this.selected,
            'aspect-ratio': true,
            'aspect-ratio--1x1': true
        });
        return (h("div", { onClick: () => this._itemSelectedHandler(), class: "fl w-100 w-50-m  w-25-ns pa2" },
            h("div", { class: classes },
                h("img", { src: thumbnail.id, class: "db bg-center cover aspect-ratio--object" })),
            this.renderLabel()));
    }
    _itemSelectedHandler() {
        this.onSelectItem.emit(this.item);
    }
    static get is() { return "iiif-gallery-item"; }
    static get properties() { return {
        "item": {
            "type": "Any",
            "attr": "item"
        },
        "selected": {
            "type": Boolean,
            "attr": "selected"
        }
    }; }
    static get events() { return [{
            "name": "onSelectItem",
            "method": "onSelectItem",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return ""; }
}

export { IIIFGallery as IiifGallery, IIIFGalleryItem as IiifGalleryItem };
